@@ -1,13 +1,11 @@
 import os
 import pkg_resources
 
-from pyramid.compat import string_types
-
-from pyramid.path import package_path, package_name
+from pyramid.path import package_name, package_path
 
 
 def resolve_asset_spec(spec, pname='__main__'):
-    if pname and not isinstance(pname, string_types):
+    if pname and not isinstance(pname, str):
         pname = pname.__name__  # as package
     if os.path.isabs(spec):
         return None, spec
@@ -20,9 +18,9 @@ def resolve_asset_spec(spec, pname='__main__'):
 
 
 def asset_spec_from_abspath(abspath, package):
-    """ Try to convert an absolute path to a resource in a package to
+    """Try to convert an absolute path to a resource in a package to
     a resource specification if possible; otherwise return the
-    absolute path.  """
+    absolute path."""
     if getattr(package, '__name__', None) == '__main__':
         return abspath
     pp = package_path(package) + os.path.sep
