@@ -35,7 +35,7 @@ class ActionConfiguratorMixin:
         kw=None,
         order=0,
         introspectables=(),
-        **extra
+        **extra,
     ):
         """Register an action which will be executed when
         :meth:`pyramid.config.Configurator.commit` is called (or executed
@@ -185,7 +185,7 @@ class ActionState:
         includepath=(),
         info=None,
         introspectables=(),
-        **extra
+        **extra,
     ):
         """Add an action with the given discriminator, callable, and
         arguments"""
@@ -557,13 +557,6 @@ def action_method(wrapped):
         if info is None:
             try:
                 f = traceback.extract_stack(limit=4)
-
-                # Work around a Python 3.5 issue whereby it would insert an
-                # extra stack frame. This should no longer be necessary in
-                # Python 3.5.1
-                last_frame = ActionInfo(*f[-1])
-                if last_frame.function == 'extract_stack':  # pragma: no cover
-                    f.pop()
                 info = ActionInfo(*f[-backframes])
             except Exception:  # pragma: no cover
                 info = ActionInfo(None, 0, '', '')
