@@ -221,7 +221,7 @@ def get_localizer(request):
 
 
 class Translations(gettext.GNUTranslations):
-    """An extended translation catalog class (ripped off from Babel) """
+    """An extended translation catalog class (ripped off from Babel)"""
 
     DEFAULT_DOMAIN = 'messages'
 
@@ -335,12 +335,6 @@ class Translations(gettext.GNUTranslations):
         """
         return self._domains.get(domain, self).gettext(message)
 
-    def ldgettext(self, domain, message):
-        """Like ``lgettext()``, but look the message up in the specified
-        domain.
-        """
-        return self._domains.get(domain, self).lgettext(message)
-
     def dugettext(self, domain, message):
         """Like ``ugettext()``, but look the message up in the specified
         domain.
@@ -353,12 +347,6 @@ class Translations(gettext.GNUTranslations):
         """
         return self._domains.get(domain, self).ngettext(singular, plural, num)
 
-    def ldngettext(self, domain, singular, plural, num):
-        """Like ``lngettext()``, but look the message up in the specified
-        domain.
-        """
-        return self._domains.get(domain, self).lngettext(singular, plural, num)
-
     def dungettext(self, domain, singular, plural, num):
         """Like ``ungettext()`` but look the message up in the specified
         domain.
@@ -369,7 +357,7 @@ class Translations(gettext.GNUTranslations):
 class LocalizerRequestMixin:
     @reify
     def localizer(self):
-        """ Convenience property to return a localizer """
+        """Convenience property to return a localizer"""
         registry = self.registry
 
         current_locale_name = self.locale_name
