@@ -138,11 +138,11 @@ class static_view:
 
         # normalize asset spec or fs path into resource_path
         if self.package_name:  # package resource
-            resource_path = '%s/%s' % (self.docroot.rstrip('/'), path)
+            resource_path = '{}/{}'.format(self.docroot.rstrip('/'), path)
             if resource_isdir(self.package_name, resource_path):
                 if not request.path_url.endswith('/'):
                     raise self.add_slash_redirect(request)
-                resource_path = '%s/%s' % (
+                resource_path = '{}/{}'.format(
                     resource_path.rstrip('/'),
                     self.index,
                 )
@@ -171,7 +171,7 @@ class static_view:
             return name
 
     def get_possible_files(self, resource_name):
-        """ Return a sorted list of ``(size, encoding, path)`` entries."""
+        """Return a sorted list of ``(size, encoding, path)`` entries."""
         result = self.filemap.get(resource_name)
         if result is not None:
             return result
@@ -206,7 +206,7 @@ class static_view:
         return result
 
     def find_best_match(self, request, files):
-        """ Return ``(path | None, encoding)``."""
+        """Return ``(path | None, encoding)``."""
         # if the client did not specify encodings then assume only the
         # identity is acceptable
         if not request.accept_encoding:
@@ -260,12 +260,12 @@ def _add_vary(response, option):
     response.vary = vary
 
 
-_seps = {'/', os.sep}
+_invalid_element_chars = {'/', os.sep, '\x00'}
 
 
-def _contains_slash(item):
-    for sep in _seps:
-        if sep in item:
+def _contains_invalid_element_char(item):
+    for invalid_element_char in _invalid_element_chars:
+        if invalid_element_char in item:
             return True
 
 
@@ -279,7 +279,7 @@ def _secure_path(path_tuple):
         # unless someone screws up the traversal_path code
         # (request.subpath is computed via traversal_path too)
         return None
-    if any([_contains_slash(item) for item in path_tuple]):
+    if any([_contains_invalid_element_char(item) for item in path_tuple]):
         return None
     encoded = '/'.join(path_tuple)  # will be unicode
     return encoded
@@ -408,7 +408,7 @@ class ManifestCacheBuster:
 
     @property
     def manifest(self):
-        """ The current manifest dictionary."""
+        """The current manifest dictionary."""
         if self.reload:
             if not self.exists(self.manifest_path):
                 return {}
