@@ -1,20 +1,19 @@
 """ Utility functions for dealing with URLs in pyramid """
 
+from functools import lru_cache
 import os
 
-from pyramid.interfaces import IResourceURL, IRoutesMapper, IStaticURLInfo
-
-from pyramid.compat import bytes_, lru_cache, string_types
 from pyramid.encode import url_quote, urlencode
+from pyramid.interfaces import IResourceURL, IRoutesMapper, IStaticURLInfo
 from pyramid.path import caller_package
 from pyramid.threadlocal import get_current_registry
-
 from pyramid.traversal import (
-    ResourceURL,
-    quote_path_segment,
     PATH_SAFE,
     PATH_SEGMENT_SAFE,
+    ResourceURL,
+    quote_path_segment,
 )
+from pyramid.util import bytes_
 
 QUERY_SAFE = "/?:@!$&'()*+,;="  # RFC 3986
 ANCHOR_SAFE = QUERY_SAFE
@@ -45,7 +44,7 @@ def parse_url_overrides(request, kw):
 
     qs = ''
     if query:
-        if isinstance(query, string_types):
+        if isinstance(query, str):
             qs = '?' + url_quote(query, QUERY_SAFE)
         else:
             qs = '?' + urlencode(query, doseq=True)
@@ -57,9 +56,9 @@ def parse_url_overrides(request, kw):
     return app_url, qs, frag
 
 
-class URLMethodsMixin(object):
-    """ Request methods mixin for BaseRequest having to do with URL
-    generation """
+class URLMethodsMixin:
+    """Request methods mixin for BaseRequest having to do with URL
+    generation"""
 
     def _partial_application_url(self, scheme=None, host=None, port=None):
         """
