@@ -1,7 +1,9 @@
+from http.cookies import SimpleCookie
 import unittest
 import warnings
+
 from pyramid import testing
-from pyramid.compat import text_, bytes_
+from pyramid.util import bytes_, text_
 
 
 class TestCallbackAuthenticationPolicyDebugging(unittest.TestCase):
@@ -237,12 +239,14 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
 
     def test_class_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyClass(IAuthenticationPolicy, self._getTargetClass())
 
     def test_instance_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyObject(IAuthenticationPolicy, self._makeOne())
@@ -319,15 +323,14 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.authenticated_userid(request), None)
 
     def test_effective_principals_None(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest({})
         policy = self._makeOne()
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals_userid_only(self):
-        from pyramid.security import Everyone
-        from pyramid.security import Authenticated
+        from pyramid.authorization import Authenticated, Everyone
 
         request = DummyRequest(
             {'repoze.who.identity': {'repoze.who.userid': 'fred'}}
@@ -339,8 +342,7 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
         )
 
     def test_effective_principals_userid_and_groups(self):
-        from pyramid.security import Everyone
-        from pyramid.security import Authenticated
+        from pyramid.authorization import Authenticated, Everyone
 
         request = DummyRequest(
             {
@@ -361,7 +363,7 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
         )
 
     def test_effective_principals_userid_callback_returns_None(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest(
             {
@@ -379,7 +381,7 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals_repoze_who_userid_is_None(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest(
             {'repoze.who.identity': {'repoze.who.userid': None}}
@@ -388,7 +390,7 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals_repoze_who_userid_is_unclean_Everyone(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest(
             {'repoze.who.identity': {'repoze.who.userid': 'system.Everyone'}}
@@ -397,9 +399,9 @@ class TestRepozeWho1AuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals_repoze_who_userid_is_unclean_Authenticated(
-        self
+        self,
     ):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest(
             {
@@ -465,12 +467,14 @@ class TestRemoteUserAuthenticationPolicy(unittest.TestCase):
 
     def test_class_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyClass(IAuthenticationPolicy, self._getTargetClass())
 
     def test_instance_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyObject(IAuthenticationPolicy, self._makeOne())
@@ -496,15 +500,14 @@ class TestRemoteUserAuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.authenticated_userid(request), 'fred')
 
     def test_effective_principals_None(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest({})
         policy = self._makeOne()
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals(self):
-        from pyramid.security import Everyone
-        from pyramid.security import Authenticated
+        from pyramid.authorization import Authenticated, Everyone
 
         request = DummyRequest({'REMOTE_USER': 'fred'})
         policy = self._makeOne()
@@ -599,14 +602,14 @@ class TestAuthTktAuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.authenticated_userid(request), 'fred')
 
     def test_effective_principals_no_cookie_identity(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest({})
         policy = self._makeOne(None, None)
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals_callback_returns_None(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest({})
 
@@ -617,8 +620,7 @@ class TestAuthTktAuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals(self):
-        from pyramid.security import Everyone
-        from pyramid.security import Authenticated
+        from pyramid.authorization import Authenticated, Everyone
 
         request = DummyRequest({})
 
@@ -652,12 +654,14 @@ class TestAuthTktAuthenticationPolicy(unittest.TestCase):
 
     def test_class_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyClass(IAuthenticationPolicy, self._getTargetClass())
 
     def test_instance_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyObject(IAuthenticationPolicy, self._makeOne(None, None))
@@ -706,8 +710,6 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         return cookie
 
     def _parseCookie(self, cookie):
-        from pyramid.compat import SimpleCookie
-
         cookies = SimpleCookie()
         cookies.load(cookie)
         return cookies.get('auth_tkt')
@@ -915,7 +917,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         self.assertEqual(len(request.callbacks), 1)
         response = DummyResponse()
         request.callbacks[0](request, response)
-        self.assertEqual(len(response.headerlist), 3)
+        self.assertEqual(len(response.headerlist), 1)
         self.assertEqual(response.headerlist[0][0], 'Set-Cookie')
 
     def test_identify_cookie_str_reissue(self):
@@ -932,7 +934,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         self.assertEqual(len(request.callbacks), 1)
         response = DummyResponse()
         request.callbacks[0](request, response)
-        self.assertEqual(len(response.headerlist), 3)
+        self.assertEqual(len(response.headerlist), 1)
         self.assertEqual(response.headerlist[0][0], 'Set-Cookie')
 
     def test_identify_cookie_reissue_already_reissued_this_request(self):
@@ -1015,7 +1017,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         self.assertEqual(len(request.callbacks), 1)
         response = DummyResponse()
         request.callbacks[0](None, response)
-        self.assertEqual(len(response.headerlist), 3)
+        self.assertEqual(len(response.headerlist), 1)
         self.assertEqual(response.headerlist[0][0], 'Set-Cookie')
         self.assertTrue("/tokens=/" in response.headerlist[0][1])
 
@@ -1023,89 +1025,52 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         helper = self._makeOne('secret')
         request = self._makeRequest()
         result = helper.remember(request, 'userid')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue(result[0][1].endswith('; Path=/; SameSite=Lax'))
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            result[1][1].endswith('; Domain=localhost; Path=/; SameSite=Lax')
+            value.endswith('; Domain=localhost; Path=/; SameSite=Lax')
         )
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue(
-            result[2][1].endswith('; Domain=.localhost; Path=/; SameSite=Lax')
-        )
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_nondefault_samesite(self):
         helper = self._makeOne('secret', samesite='Strict')
         request = self._makeRequest()
         result = helper.remember(request, 'userid')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue(result[0][1].endswith('; Path=/; SameSite=Strict'))
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            result[1][1].endswith(
-                '; Domain=localhost; Path=/; SameSite=Strict'
-            )
+            value.endswith('; Domain=localhost; Path=/; SameSite=Strict')
         )
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue(
-            result[2][1].endswith(
-                '; Domain=.localhost; Path=/; SameSite=Strict'
-            )
-        )
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_None_samesite(self):
         helper = self._makeOne('secret', samesite=None)
         request = self._makeRequest()
         result = helper.remember(request, 'userid')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue(result[0][1].endswith('; Path=/'))  # no samesite
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        self.assertTrue(result[1][1].endswith('; Domain=localhost; Path=/'))
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue(result[2][1].endswith('; Domain=.localhost; Path=/'))
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
+        self.assertTrue('SameSite=' not in value)
+        self.assertTrue(value.endswith('; Domain=localhost; Path=/'))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_include_ip(self):
         helper = self._makeOne('secret', include_ip=True)
         request = self._makeRequest()
         result = helper.remember(request, 'other')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue(result[0][1].endswith('; Path=/; SameSite=Lax'))
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            result[1][1].endswith('; Domain=localhost; Path=/; SameSite=Lax')
+            value.endswith('; Domain=localhost; Path=/; SameSite=Lax')
         )
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue(
-            result[2][1].endswith('; Domain=.localhost; Path=/; SameSite=Lax')
-        )
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_path(self):
         helper = self._makeOne(
@@ -1113,81 +1078,50 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         )
         request = self._makeRequest()
         result = helper.remember(request, 'other')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            result[0][1].endswith('; Path=/cgi-bin/app.cgi/; SameSite=Lax')
-        )
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        self.assertTrue(
-            result[1][1].endswith(
+            value.endswith(
                 '; Domain=localhost; Path=/cgi-bin/app.cgi/; SameSite=Lax'
             )
         )
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue(
-            result[2][1].endswith(
-                '; Domain=.localhost; Path=/cgi-bin/app.cgi/; SameSite=Lax'
-            )
-        )
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_http_only(self):
         helper = self._makeOne('secret', include_ip=True, http_only=True)
         request = self._makeRequest()
         result = helper.remember(request, 'other')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue(result[0][1].endswith('; HttpOnly; SameSite=Lax'))
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        self.assertTrue('; HttpOnly' in result[1][1])
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue('; HttpOnly' in result[2][1])
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
+        self.assertTrue(value.endswith('; HttpOnly; SameSite=Lax'))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_secure(self):
         helper = self._makeOne('secret', include_ip=True, secure=True)
         request = self._makeRequest()
         result = helper.remember(request, 'other')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue('; secure' in result[0][1])
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        self.assertTrue('; secure' in result[1][1])
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue('; secure' in result[2][1])
-        self.assertTrue(result[2][1].startswith('auth_tkt='))
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
+        self.assertTrue('; secure' in value)
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_wild_domain_disabled(self):
         helper = self._makeOne('secret', wild_domain=False)
         request = self._makeRequest()
         result = helper.remember(request, 'other')
-        self.assertEqual(len(result), 2)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue(result[0][1].endswith('; Path=/; SameSite=Lax'))
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        self.assertTrue(
-            result[1][1].endswith('; Domain=localhost; Path=/; SameSite=Lax')
-        )
-        self.assertTrue(result[1][1].startswith('auth_tkt='))
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
+        self.assertTrue('Domain=' not in value)
+        self.assertTrue(value.endswith('; Path=/; SameSite=Lax'))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_parent_domain(self):
         helper = self._makeOne('secret', parent_domain=True)
@@ -1196,13 +1130,12 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         result = helper.remember(request, 'other')
         self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            result[0][1].endswith(
-                '; Domain=.example.com; Path=/; SameSite=Lax'
-            )
+            value.endswith('; Domain=example.com; Path=/; SameSite=Lax')
         )
-        self.assertTrue(result[0][1].startswith('auth_tkt='))
+        self.assertTrue(value.startswith('auth_tkt='))
 
     def test_remember_parent_domain_supercedes_wild_domain(self):
         helper = self._makeOne('secret', parent_domain=True, wild_domain=True)
@@ -1210,10 +1143,10 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         request.domain = 'www.example.com'
         result = helper.remember(request, 'other')
         self.assertEqual(len(result), 1)
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            result[0][1].endswith(
-                '; Domain=.example.com; Path=/; SameSite=Lax'
-            )
+            value.endswith('; Domain=example.com; Path=/; SameSite=Lax')
         )
 
     def test_remember_explicit_domain(self):
@@ -1255,7 +1188,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         request = self._makeRequest()
         result = helper.remember(request, b'userid')
         values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
         val = self._cookieValue(values[0])
         self.assertEqual(
             val['userid'], text_(base64.b64encode(b'userid').strip())
@@ -1267,19 +1200,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         request = self._makeRequest()
         result = helper.remember(request, 1)
         values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
-        val = self._cookieValue(values[0])
-        self.assertEqual(val['userid'], '1')
-        self.assertEqual(val['user_data'], 'userid_type:int')
-
-    def test_remember_long_userid(self):
-        from pyramid.compat import long
-
-        helper = self._makeOne('secret')
-        request = self._makeRequest()
-        result = helper.remember(request, long(1))
-        values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
         val = self._cookieValue(values[0])
         self.assertEqual(val['userid'], '1')
         self.assertEqual(val['user_data'], 'userid_type:int')
@@ -1292,7 +1213,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         userid = text_(b'\xc2\xa9', 'utf-8')
         result = helper.remember(request, userid)
         values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
         val = self._cookieValue(values[0])
         self.assertEqual(
             val['userid'], text_(base64.b64encode(userid.encode('utf-8')))
@@ -1308,7 +1229,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
             result = helper.remember(request, userid)
             self.assertTrue(str(w[-1].message).startswith('userid is of type'))
         values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
         value = values[0]
         self.assertTrue('userid' in value.value)
 
@@ -1317,7 +1238,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         request = self._makeRequest()
         result = helper.remember(request, 'userid', max_age=500)
         values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
         self.assertEqual(values[0]['max-age'], '500')
         self.assertTrue(values[0]['expires'])
@@ -1327,7 +1248,7 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         request = self._makeRequest()
         result = helper.remember(request, 'userid', max_age='500')
         values = self._parseHeaders(result)
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
         self.assertEqual(values[0]['max-age'], '500')
         self.assertTrue(values[0]['expires'])
@@ -1347,69 +1268,36 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         helper = self._makeOne('secret')
         request = self._makeRequest()
         result = helper.remember(request, 'other', tokens=('foo', 'bar'))
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        self.assertTrue("/tokens=foo|bar/" in result[0][1])
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        self.assertTrue("/tokens=foo|bar/" in result[1][1])
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        self.assertTrue("/tokens=foo|bar/" in result[2][1])
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
+        self.assertTrue("/tokens=foo|bar/" in value)
 
     def test_remember_samesite_nondefault(self):
         helper = self._makeOne('secret', samesite='Strict')
         request = self._makeRequest()
         result = helper.remember(request, 'userid')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        cookieval = result[0][1]
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            'SameSite=Strict' in [x.strip() for x in cookieval.split(';')],
-            cookieval,
-        )
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        cookieval = result[1][1]
-        self.assertTrue(
-            'SameSite=Strict' in [x.strip() for x in cookieval.split(';')],
-            cookieval,
-        )
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        cookieval = result[2][1]
-        self.assertTrue(
-            'SameSite=Strict' in [x.strip() for x in cookieval.split(';')],
-            cookieval,
+            'SameSite=Strict' in [x.strip() for x in value.split(';')],
+            value,
         )
 
     def test_remember_samesite_default(self):
         helper = self._makeOne('secret')
         request = self._makeRequest()
         result = helper.remember(request, 'userid')
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 1)
 
-        self.assertEqual(result[0][0], 'Set-Cookie')
-        cookieval = result[0][1]
+        name, value = result[0]
+        self.assertEqual(name, 'Set-Cookie')
         self.assertTrue(
-            'SameSite=Lax' in [x.strip() for x in cookieval.split(';')],
-            cookieval,
-        )
-
-        self.assertEqual(result[1][0], 'Set-Cookie')
-        cookieval = result[1][1]
-        self.assertTrue(
-            'SameSite=Lax' in [x.strip() for x in cookieval.split(';')],
-            cookieval,
-        )
-
-        self.assertEqual(result[2][0], 'Set-Cookie')
-        cookieval = result[2][1]
-        self.assertTrue(
-            'SameSite=Lax' in [x.strip() for x in cookieval.split(';')],
-            cookieval,
+            'SameSite=Lax' in [x.strip() for x in value.split(';')],
+            value,
         )
 
     def test_remember_unicode_but_ascii_token(self):
@@ -1442,28 +1330,14 @@ class TestAuthTktCookieHelper(unittest.TestCase):
         helper = self._makeOne('secret')
         request = self._makeRequest()
         headers = helper.forget(request)
-        self.assertEqual(len(headers), 3)
+        self.assertEqual(len(headers), 1)
         name, value = headers[0]
         self.assertEqual(name, 'Set-Cookie')
-        self.assertEqual(
-            value,
-            'auth_tkt=; Max-Age=0; Path=/; '
-            'expires=Wed, 31-Dec-97 23:59:59 GMT; SameSite=Lax',
-        )
-        name, value = headers[1]
-        self.assertEqual(name, 'Set-Cookie')
         self.assertEqual(
             value,
             'auth_tkt=; Domain=localhost; Max-Age=0; Path=/; '
             'expires=Wed, 31-Dec-97 23:59:59 GMT; SameSite=Lax',
         )
-        name, value = headers[2]
-        self.assertEqual(name, 'Set-Cookie')
-        self.assertEqual(
-            value,
-            'auth_tkt=; Domain=.localhost; Max-Age=0; Path=/; '
-            'expires=Wed, 31-Dec-97 23:59:59 GMT; SameSite=Lax',
-        )
 
 
 class TestAuthTicket(unittest.TestCase):
@@ -1608,12 +1482,14 @@ class TestSessionAuthenticationPolicy(unittest.TestCase):
 
     def test_class_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyClass(IAuthenticationPolicy, self._getTargetClass())
 
     def test_instance_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyObject(IAuthenticationPolicy, self._makeOne())
@@ -1652,14 +1528,14 @@ class TestSessionAuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.authenticated_userid(request), 'fred')
 
     def test_effective_principals_no_identity(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest()
         policy = self._makeOne()
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals_callback_returns_None(self):
-        from pyramid.security import Everyone
+        from pyramid.authorization import Everyone
 
         request = DummyRequest(session={'userid': 'fred'})
 
@@ -1670,8 +1546,7 @@ class TestSessionAuthenticationPolicy(unittest.TestCase):
         self.assertEqual(policy.effective_principals(request), [Everyone])
 
     def test_effective_principals(self):
-        from pyramid.security import Everyone
-        from pyramid.security import Authenticated
+        from pyramid.authorization import Authenticated, Everyone
 
         request = DummyRequest(session={'userid': 'fred'})
 
@@ -1706,6 +1581,56 @@ class TestSessionAuthenticationPolicy(unittest.TestCase):
         self.assertEqual(result, [])
 
 
+class TestSessionAuthenticationHelper(unittest.TestCase):
+    def _makeRequest(self, session=None):
+        from types import SimpleNamespace
+
+        if session is None:
+            session = dict()
+        return SimpleNamespace(session=session)
+
+    def _makeOne(self, prefix=''):
+        from pyramid.authentication import SessionAuthenticationHelper
+
+        return SessionAuthenticationHelper(prefix=prefix)
+
+    def test_authenticated_userid(self):
+        request = self._makeRequest({'userid': 'fred'})
+        helper = self._makeOne()
+        self.assertEqual(helper.authenticated_userid(request), 'fred')
+
+    def test_authenticated_userid_with_prefix(self):
+        request = self._makeRequest({'foo.userid': 'fred'})
+        helper = self._makeOne(prefix='foo.')
+        self.assertEqual(helper.authenticated_userid(request), 'fred')
+
+    def test_authenticated_userid_none(self):
+        request = self._makeRequest()
+        helper = self._makeOne()
+        self.assertEqual(helper.authenticated_userid(request), None)
+
+    def test_remember(self):
+        request = self._makeRequest()
+        helper = self._makeOne()
+        result = helper.remember(request, 'fred')
+        self.assertEqual(request.session.get('userid'), 'fred')
+        self.assertEqual(result, [])
+
+    def test_forget(self):
+        request = self._makeRequest({'userid': 'fred'})
+        helper = self._makeOne()
+        result = helper.forget(request)
+        self.assertEqual(request.session.get('userid'), None)
+        self.assertEqual(result, [])
+
+    def test_forget_no_identity(self):
+        request = self._makeRequest()
+        helper = self._makeOne()
+        result = helper.forget(request)
+        self.assertEqual(request.session.get('userid'), None)
+        self.assertEqual(result, [])
+
+
 class TestBasicAuthAuthenticationPolicy(unittest.TestCase):
     def _getTargetClass(self):
         from pyramid.authentication import BasicAuthAuthenticationPolicy as cls
@@ -1717,6 +1642,7 @@ class TestBasicAuthAuthenticationPolicy(unittest.TestCase):
 
     def test_class_implements_IAuthenticationPolicy(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IAuthenticationPolicy
 
         verifyClass(IAuthenticationPolicy, self._getTargetClass())
@@ -1924,7 +1850,7 @@ class DummyContext:
     pass
 
 
-class DummyCookies(object):
+class DummyCookies:
     def __init__(self, cookie):
         self.cookie = cookie
 
@@ -1969,7 +1895,7 @@ class DummyCookieHelper:
         return []
 
 
-class DummyAuthTktModule(object):
+class DummyAuthTktModule:
     def __init__(
         self,
         timestamp=0,
@@ -1996,7 +1922,7 @@ class DummyAuthTktModule(object):
 
         self.parse_ticket = parse_ticket
 
-        class AuthTicket(object):
+        class AuthTicket:
             def __init__(self, secret, userid, remote_addr, **kw):
                 self.secret = secret
                 self.userid = userid
