@@ -1,6 +1,5 @@
-import unittest
 import os
-from pyramid.compat import PY2
+import unittest
 
 here = os.path.abspath(os.path.dirname(__file__))
 
@@ -29,6 +28,7 @@ class TestCallerPath(unittest.TestCase):
 
     def test_memoization_has_abspath(self):
         import os
+
         from . import test_path
 
         test_path.__abspath__ = '/foo/bar'
@@ -37,6 +37,7 @@ class TestCallerPath(unittest.TestCase):
 
     def test_memoization_success(self):
         import os
+
         from . import test_path
 
         result = self._callFUT('a/b/c')
@@ -69,10 +70,10 @@ class TestCallerModule(unittest.TestCase):
         self.assertNotEqual(result, test_path)
 
     def test_it_no___name__(self):
-        class DummyFrame(object):
+        class DummyFrame:
             f_globals = {}
 
-        class DummySys(object):
+        class DummySys:
             def _getframe(self, level):
                 return DummyFrame()
 
@@ -167,8 +168,8 @@ class TestPackageOf(unittest.TestCase):
         self.assertEqual(result, tests)
 
     def test_it_module(self):
-        import tests.test_path
         import tests
+        import tests.test_path
 
         package = DummyPackageOrModule(tests.test_path)
         result = self._callFUT(package)
@@ -223,8 +224,8 @@ class TestResolver(unittest.TestCase):
         return self._getTargetClass()(package)
 
     def test_get_package_caller_package(self):
-        import tests
         from pyramid.path import CALLER_PACKAGE
+        import tests
 
         self.assertEqual(self._makeOne(CALLER_PACKAGE).get_package(), tests)
 
@@ -296,8 +297,7 @@ class TestAssetResolver(unittest.TestCase):
         self.assertRaises(ValueError, inst.resolve, 'test_asset.py')
 
     def test_resolve_relspec_caller_package(self):
-        from pyramid.path import PkgResourcesAssetDescriptor
-        from pyramid.path import CALLER_PACKAGE
+        from pyramid.path import CALLER_PACKAGE, PkgResourcesAssetDescriptor
 
         inst = self._makeOne(CALLER_PACKAGE)
         r = inst.resolve('test_asset.py')
@@ -315,15 +315,17 @@ class TestPkgResourcesAssetDescriptor(unittest.TestCase):
         return self._getTargetClass()(pkg, path)
 
     def test_class_conforms_to_IAssetDescriptor(self):
-        from pyramid.interfaces import IAssetDescriptor
         from zope.interface.verify import verifyClass
 
+        from pyramid.interfaces import IAssetDescriptor
+
         verifyClass(IAssetDescriptor, self._getTargetClass())
 
     def test_instance_conforms_to_IAssetDescriptor(self):
-        from pyramid.interfaces import IAssetDescriptor
         from zope.interface.verify import verifyObject
 
+        from pyramid.interfaces import IAssetDescriptor
+
         verifyObject(IAssetDescriptor, self._makeOne())
 
     def test_absspec(self):
@@ -370,15 +372,17 @@ class TestFSAssetDescriptor(unittest.TestCase):
         return self._getTargetClass()(path)
 
     def test_class_conforms_to_IAssetDescriptor(self):
-        from pyramid.interfaces import IAssetDescriptor
         from zope.interface.verify import verifyClass
 
+        from pyramid.interfaces import IAssetDescriptor
+
         verifyClass(IAssetDescriptor, self._getTargetClass())
 
     def test_instance_conforms_to_IAssetDescriptor(self):
-        from pyramid.interfaces import IAssetDescriptor
         from zope.interface.verify import verifyObject
 
+        from pyramid.interfaces import IAssetDescriptor
+
         verifyObject(IAssetDescriptor, self._makeOne())
 
     def test_absspec(self):
@@ -429,10 +433,7 @@ class TestDottedNameResolver(unittest.TestCase):
 
     def test_zope_dottedname_style_resolve_builtin(self):
         typ = self._makeOne()
-        if PY2:
-            result = typ._zope_dottedname_style('__builtin__.str', None)
-        else:
-            result = typ._zope_dottedname_style('builtins.str', None)
+        result = typ._zope_dottedname_style('builtins.str', None)
         self.assertEqual(result, str)
 
     def test_zope_dottedname_style_resolve_absolute(self):
@@ -615,6 +616,7 @@ class TestDottedNameResolver(unittest.TestCase):
 
     def test_ctor_module(self):
         import tests
+
         from . import test_path
 
         typ = self._makeOne(test_path)
@@ -631,7 +633,7 @@ class TestDottedNameResolver(unittest.TestCase):
         self.assertEqual(typ.package, None)
 
 
-class DummyPkgResource(object):
+class DummyPkgResource:
     pass
 
 
@@ -653,8 +655,7 @@ class DummyPackageOrModule:
 
 
 class DummyNamespacePackage:
-    """Has no __file__ attribute.
-    """
+    """Has no __file__ attribute."""
 
     def __init__(self, real_package_or_module):
         self.__name__ = real_package_or_module.__name__
