@@ -1,16 +1,15 @@
+from io import StringIO
 import os
 import unittest
-from . import dummy
 
+from . import dummy
 
 here = os.path.abspath(os.path.dirname(__file__))
 
 
 class TestPServeCommand(unittest.TestCase):
     def setUp(self):
-        from pyramid.compat import NativeIO
-
-        self.out_ = NativeIO()
+        self.out_ = StringIO()
 
     def out(self, msg):
         self.out_.write(msg)
@@ -90,13 +89,11 @@ class TestPServeCommand(unittest.TestCase):
         self.assertEqual(loader.calls[0]['defaults'], {'a': '1'})
         self.assertEqual(
             inst.watch_files,
-            set(
-                [
-                    os.path.abspath('/base/foo'),
-                    os.path.abspath('/baz'),
-                    os.path.abspath(os.path.join(here, '*.py')),
-                ]
-            ),
+            {
+                os.path.abspath('/base/foo'),
+                os.path.abspath('/baz'),
+                os.path.abspath(os.path.join(here, '*.py')),
+            },
         )
 
     def test_config_file_finds_open_url(self):
@@ -120,7 +117,7 @@ class TestPServeCommand(unittest.TestCase):
 
         class AttrDict(dict):
             def __init__(self, *args, **kwargs):
-                super(AttrDict, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
                 self.__dict__ = self
 
         def dummy_start_reloader(*args, **kwargs):
@@ -138,10 +135,10 @@ class TestPServeCommand(unittest.TestCase):
         finally:
             pserve.hupper = orig_hupper
 
-        self.assertEquals(
+        self.assertEqual(
             dummy_start_reloader.args, ('pyramid.scripts.pserve.main',)
         )
-        self.assertEquals(
+        self.assertEqual(
             dummy_start_reloader.kwargs,
             {
                 'reload_interval': 1,
