@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 import unittest
+from urllib.parse import quote
 
 from pyramid.testing import cleanUp
-
-from pyramid.compat import text_, native_, text_type, url_quote, PY2
+from pyramid.util import text_
 
 
 class TraversalPathTests(unittest.TestCase):
@@ -14,7 +13,7 @@ class TraversalPathTests(unittest.TestCase):
 
     def test_utf8(self):
         la = b'La Pe\xc3\xb1a'
-        encoded = url_quote(la)
+        encoded = quote(la)
         decoded = text_(la, 'utf-8')
         path = '/'.join([encoded, encoded])
         result = self._callFUT(path)
@@ -24,7 +23,7 @@ class TraversalPathTests(unittest.TestCase):
         from pyramid.exceptions import URLDecodeError
 
         la = text_(b'La Pe\xc3\xb1a', 'utf-8').encode('utf-16')
-        encoded = url_quote(la)
+        encoded = quote(la)
         path = '/'.join([encoded, encoded])
         self.assertRaises(URLDecodeError, self._callFUT, path)
 
@@ -71,8 +70,8 @@ class TraversalPathInfoTests(unittest.TestCase):
 
     def test_segments_are_unicode(self):
         result = self._callFUT('/foo/bar')
-        self.assertEqual(type(result[0]), text_type)
-        self.assertEqual(type(result[1]), text_type)
+        self.assertEqual(type(result[0]), str)
+        self.assertEqual(type(result[1]), str)
 
     def test_same_value_returned_if_cached(self):
         result1 = self._callFUT('/foo/bar')
@@ -86,15 +85,14 @@ class TraversalPathInfoTests(unittest.TestCase):
 
     def test_highorder(self):
         la = b'La Pe\xc3\xb1a'
-        latin1 = native_(la)
+        latin1 = text_(la)
         result = self._callFUT(latin1)
         self.assertEqual(result, (text_(la, 'utf-8'),))
 
     def test_highorder_undecodeable(self):
         from pyramid.exceptions import URLDecodeError
 
-        la = text_(b'La Pe\xc3\xb1a', 'utf-8')
-        notlatin1 = native_(la)
+        notlatin1 = text_(b'La Pe\xc3\xb1a', 'utf-8')
         self.assertRaises(URLDecodeError, self._callFUT, notlatin1)
 
 
@@ -121,12 +119,14 @@ class ResourceTreeTraverserTests(unittest.TestCase):
 
     def test_class_conforms_to_ITraverser(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import ITraverser
 
         verifyClass(ITraverser, self._getTargetClass())
 
     def test_instance_conforms_to_ITraverser(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import ITraverser
 
         context = DummyContext()
@@ -346,10 +346,7 @@ class ResourceTreeTraverserTests(unittest.TestCase):
         foo = DummyContext(bar, path)
         root = DummyContext(foo, 'root')
         policy = self._makeOne(root)
-        if PY2:
-            vhm_root = b'/Qu\xc3\xa9bec'
-        else:
-            vhm_root = b'/Qu\xc3\xa9bec'.decode('latin-1')
+        vhm_root = b'/Qu\xc3\xa9bec'.decode('latin-1')
         environ = self._getEnviron(HTTP_X_VHM_ROOT=vhm_root)
         request = DummyRequest(environ, path_info=text_('/bar'))
         result = policy(request)
@@ -499,8 +496,7 @@ class FindInterfaceTests(unittest.TestCase):
         bar.__name__ = 'bar'
         baz.__parent__ = bar
         baz.__name__ = 'baz'
-        from zope.interface import directlyProvides
-        from zope.interface import Interface
+        from zope.interface import Interface, directlyProvides
 
         class IFoo(Interface):
             pass
@@ -510,7 +506,7 @@ class FindInterfaceTests(unittest.TestCase):
         self.assertEqual(result.__name__, 'root')
 
     def test_it_class(self):
-        class DummyRoot(object):
+        class DummyRoot:
             def __init__(self, child):
                 self.child = child
 
@@ -557,9 +553,10 @@ class FindResourceTests(unittest.TestCase):
         from pyramid.threadlocal import get_current_registry
 
         reg = get_current_registry()
-        from pyramid.interfaces import ITraverser
         from zope.interface import Interface
 
+        from pyramid.interfaces import ITraverser
+
         reg.registerAdapter(traverser, (Interface,), ITraverser)
 
     def test_list(self):
@@ -680,7 +677,7 @@ class FindResourceTests(unittest.TestCase):
 
     def test_absolute_unicode_found(self):
         # test for bug wiggy found in wild, traceback stack:
-        # root = u'/%E6%B5%81%E8%A1%8C%E8%B6%8B%E5%8A%BF'
+        # root = '/%E6%B5%81%E8%A1%8C%E8%B6%8B%E5%8A%BF'
         # wiggy's code: section=find_resource(page, root)
         # find_resource L76: D = traverse(resource, path)
         # traverse L291: return traverser(request)
@@ -873,17 +870,8 @@ class QuotePathSegmentTests(unittest.TestCase):
         result = self._callFUT(s)
         self.assertEqual(result, '12345')
 
-    def test_long(self):
-        from pyramid.compat import long
-        import sys
-
-        s = long(sys.maxsize + 1)
-        result = self._callFUT(s)
-        expected = str(s)
-        self.assertEqual(result, expected)
-
     def test_other(self):
-        class Foo(object):
+        class Foo:
             def __str__(self):
                 return 'abc'
 
@@ -902,9 +890,10 @@ class ResourceURLTests(unittest.TestCase):
         return ResourceURL
 
     def test_instance_conforms_to_IResourceURL(self):
-        from pyramid.interfaces import IResourceURL
         from zope.interface.verify import verifyObject
 
+        from pyramid.interfaces import IResourceURL
+
         context = DummyContext()
         request = DummyRequest()
         verifyObject(IResourceURL, self._makeOne(context, request))
@@ -992,9 +981,10 @@ class TestVirtualRoot(unittest.TestCase):
         from pyramid.threadlocal import get_current_registry
 
         reg = get_current_registry()
-        from pyramid.interfaces import ITraverser
         from zope.interface import Interface
 
+        from pyramid.interfaces import ITraverser
+
         reg.registerAdapter(traverser, (Interface,), ITraverser)
 
     def test_virtual_root_no_virtual_root_path(self):
@@ -1065,9 +1055,10 @@ class TraverseTests(unittest.TestCase):
         from pyramid.threadlocal import get_current_registry
 
         reg = get_current_registry()
-        from pyramid.interfaces import ITraverser
         from zope.interface import Interface
 
+        from pyramid.interfaces import ITraverser
+
         reg.registerAdapter(traverser, (Interface,), ITraverser)
 
     def test_request_has_registry(self):
@@ -1201,7 +1192,7 @@ class TestDefaultRootFactory(unittest.TestCase):
         return self._getTargetClass()(environ)
 
     def test_it(self):
-        class DummyRequest(object):
+        class DummyRequest:
             pass
 
         root = self._makeOne(DummyRequest())
@@ -1226,18 +1217,18 @@ class Test__join_path_tuple(unittest.TestCase):
 
     def test_segments_with_unsafes(self):
         safe_segments = tuple(
-            u"0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
-            u"-._~!$&'()*+,;=:@"
+            "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
+            "-._~!$&'()*+,;=:@"
         )
         result = self._callFUT(safe_segments)
-        self.assertEqual(result, u'/'.join(safe_segments))
+        self.assertEqual(result, '/'.join(safe_segments))
         unsafe_segments = tuple(
             chr(i) for i in range(0x20, 0x80) if not chr(i) in safe_segments
-        ) + (u'あ',)
+        ) + ('あ',)
         result = self._callFUT(unsafe_segments)
         self.assertEqual(
             result,
-            u'/'.join(
+            '/'.join(
                 ''.join(
                     '%%%02X' % (ord(c) if isinstance(c, str) else c)
                     for c in unsafe_segment.encode('utf-8')
@@ -1248,7 +1239,7 @@ class Test__join_path_tuple(unittest.TestCase):
 
 
 def make_traverser(result):
-    class DummyTraverser(object):
+    class DummyTraverser:
         def __init__(self, context):
             self.context = context
             context.wascontext = True
@@ -1260,7 +1251,7 @@ def make_traverser(result):
     return DummyTraverser
 
 
-class DummyContext(object):
+class DummyContext:
     __parent__ = None
 
     def __init__(self, next=None, name=None):
@@ -1282,8 +1273,8 @@ class DummyContext(object):
 class DummyRequest:
 
     application_url = (
-        'http://example.com:5432'
-    )  # app_url never ends with slash
+        'http://example.com:5432'  # app_url never ends with slash
+    )
     matchdict = None
     matched_route = None
 
