@@ -1,6 +1,7 @@
 import unittest
+
 from pyramid import testing
-from pyramid.compat import text_, PY2
+from pyramid.util import text_
 
 
 class TestRoute(unittest.TestCase):
@@ -13,9 +14,10 @@ class TestRoute(unittest.TestCase):
         return self._getTargetClass()(*arg)
 
     def test_provides_IRoute(self):
-        from pyramid.interfaces import IRoute
         from zope.interface.verify import verifyObject
 
+        from pyramid.interfaces import IRoute
+
         verifyObject(IRoute, self._makeOne('name', 'pattern'))
 
     def test_ctor(self):
@@ -59,9 +61,7 @@ class RoutesMapperTests(unittest.TestCase):
     def _getRequest(self, **kw):
         from pyramid.threadlocal import get_current_registry
 
-        environ = {'SERVER_NAME': 'localhost', 'wsgi.url_scheme': 'http'}
-        environ.update(kw)
-        request = DummyRequest(environ)
+        request = DummyRequest(**kw)
         reg = get_current_registry()
         request.registry = reg
         return request
@@ -76,14 +76,15 @@ class RoutesMapperTests(unittest.TestCase):
         return klass()
 
     def test_provides_IRoutesMapper(self):
-        from pyramid.interfaces import IRoutesMapper
         from zope.interface.verify import verifyObject
 
+        from pyramid.interfaces import IRoutesMapper
+
         verifyObject(IRoutesMapper, self._makeOne())
 
     def test_no_route_matches(self):
         mapper = self._makeOne()
-        request = self._getRequest(PATH_INFO='/')
+        request = self._getRequest(path_info='/')
         result = mapper(request)
         self.assertEqual(result['match'], None)
         self.assertEqual(result['route'], None)
@@ -130,19 +131,39 @@ class RoutesMapperTests(unittest.TestCase):
 
     def test___call__pathinfo_cant_be_decoded(self):
         from pyramid.exceptions import URLDecodeError
+        from pyramid.threadlocal import get_current_registry
+
+        class DummyRequest:
+            @property
+            def path_info(self):
+                return b'\xff\xfe\xe6\x00'.decode('utf-8')
 
         mapper = self._makeOne()
-        if PY2:
-            path_info = b'\xff\xfe\xe6\x00'
-        else:
-            path_info = b'\xff\xfe\xe6\x00'.decode('latin-1')
-        request = self._getRequest(PATH_INFO=path_info)
+        request = DummyRequest()
+        request.registry = get_current_registry()
         self.assertRaises(URLDecodeError, mapper, request)
 
+    def test___call__pathinfo_KeyError(self):
+        from pyramid.threadlocal import get_current_registry
+
+        class DummyRequest:
+            @property
+            def path_info(self):
+                # if the PATH_INFO is missing from the environ
+                raise KeyError
+
+        mapper = self._makeOne()
+        mapper.connect('root', '')
+        request = DummyRequest()
+        request.registry = get_current_registry()
+        result = mapper(request)
+        self.assertEqual(result['route'], mapper.routes['root'])
+        self.assertEqual(result['match'], {})
+
     def test___call__route_matches(self):
         mapper = self._makeOne()
         mapper.connect('foo', 'archives/:action/:article')
-        request = self._getRequest(PATH_INFO='/archives/action1/article1')
+        request = self._getRequest(path_info='/archives/action1/article1')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['foo'])
         self.assertEqual(result['match']['action'], 'action1')
@@ -153,7 +174,7 @@ class RoutesMapperTests(unittest.TestCase):
         mapper.connect(
             'foo', 'archives/:action/:article', predicates=[lambda *arg: True]
         )
-        request = self._getRequest(PATH_INFO='/archives/action1/article1')
+        request = self._getRequest(path_info='/archives/action1/article1')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['foo'])
         self.assertEqual(result['match']['action'], 'action1')
@@ -167,7 +188,7 @@ class RoutesMapperTests(unittest.TestCase):
             predicates=[lambda *arg: True, lambda *arg: False],
         )
         mapper.connect('bar', 'archives/:action/:article')
-        request = self._getRequest(PATH_INFO='/archives/action1/article1')
+        request = self._getRequest(path_info='/archives/action1/article1')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['bar'])
         self.assertEqual(result['match']['action'], 'action1')
@@ -182,7 +203,7 @@ class RoutesMapperTests(unittest.TestCase):
             return True
 
         mapper.connect('foo', 'archives/:action/article1', predicates=[pred])
-        request = self._getRequest(PATH_INFO='/archives/action1/article1')
+        request = self._getRequest(path_info='/archives/action1/article1')
         mapper(request)
 
     def test_cc_bug(self):
@@ -194,13 +215,13 @@ class RoutesMapperTests(unittest.TestCase):
             'juri', 'licenses/:license_code/:license_version/:jurisdiction'
         )
 
-        request = self._getRequest(PATH_INFO='/licenses/1/v2/rdf')
+        request = self._getRequest(path_info='/licenses/1/v2/rdf')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['rdf'])
         self.assertEqual(result['match']['license_code'], '1')
         self.assertEqual(result['match']['license_version'], 'v2')
 
-        request = self._getRequest(PATH_INFO='/licenses/1/v2/usa')
+        request = self._getRequest(path_info='/licenses/1/v2/usa')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['juri'])
         self.assertEqual(result['match']['license_code'], '1')
@@ -210,7 +231,7 @@ class RoutesMapperTests(unittest.TestCase):
     def test___call__root_route_matches(self):
         mapper = self._makeOne()
         mapper.connect('root', '')
-        request = self._getRequest(PATH_INFO='/')
+        request = self._getRequest(path_info='/')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['root'])
         self.assertEqual(result['match'], {})
@@ -218,7 +239,7 @@ class RoutesMapperTests(unittest.TestCase):
     def test___call__root_route_matches2(self):
         mapper = self._makeOne()
         mapper.connect('root', '/')
-        request = self._getRequest(PATH_INFO='/')
+        request = self._getRequest(path_info='/')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['root'])
         self.assertEqual(result['match'], {})
@@ -226,7 +247,7 @@ class RoutesMapperTests(unittest.TestCase):
     def test___call__root_route_when_path_info_empty(self):
         mapper = self._makeOne()
         mapper.connect('root', '/')
-        request = self._getRequest(PATH_INFO='')
+        request = self._getRequest(path_info='')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['root'])
         self.assertEqual(result['match'], {})
@@ -234,7 +255,7 @@ class RoutesMapperTests(unittest.TestCase):
     def test___call__root_route_when_path_info_notempty(self):
         mapper = self._makeOne()
         mapper.connect('root', '/')
-        request = self._getRequest(PATH_INFO='/')
+        request = self._getRequest(path_info='/')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['root'])
         self.assertEqual(result['match'], {})
@@ -242,7 +263,7 @@ class RoutesMapperTests(unittest.TestCase):
     def test___call__no_path_info(self):
         mapper = self._makeOne()
         mapper.connect('root', '/')
-        request = self._getRequest()
+        request = self._getRequest(path_info='')
         result = mapper(request)
         self.assertEqual(result['route'], mapper.routes['root'])
         self.assertEqual(result['match'], {})
@@ -641,15 +662,17 @@ class TestCompileRouteFunctional(unittest.TestCase):
         self.generates('/foo/:abc_def', {'abc_def': '20'}, '/foo/20')
 
 
-class DummyContext(object):
+class DummyContext:
     """ """
 
 
-class DummyRequest(object):
-    def __init__(self, environ):
-        self.environ = environ
+class DummyRequest:
+    scheme = 'http'
+
+    def __init__(self, **kw):
+        self.__dict__.update(kw)
 
 
-class DummyRoute(object):
+class DummyRoute:
     def __init__(self, generator):
         self.generate = generator
